intpSettings(interpreter, debug=NULL, interpolate=NULL, length.one.as.vector=NULL,
quiet=NULL)scalaInterpreter).TRUE, the interpreter will call strintrplt on the supplied code before rTRUE, setting a vector of length one in the interpreter will result in an array of length one. If FALSE, setting a vector oscalaInterpreter,
intpEval,
intpSet,
intpGet,
intpDef,
strintrplt